unwitch-3.0.0: converts between primitives
Safe HaskellNone
LanguageHaskell2010

Unwitch.Errors

Description

Error types for fallible numeric conversions.

Synopsis

Documentation

data Overflows Source #

Indicates that a numeric conversion failed because the source value is outside the representable range of the target type.

Constructors

Overflow

The source value is above the target's upper bound.

Underflow

The source value is below the target's lower bound.

Instances

Instances details
Show Overflows Source # 
Instance details

Defined in Unwitch.Errors

Eq Overflows Source # 
Instance details

Defined in Unwitch.Errors