Unwitch.Errors
Description
Error types for fallible numeric conversions.
data Overflows Source #
Indicates that a numeric conversion failed because the source value is outside the representable range of the target type.
Constructors
The source value is above the target's upper bound.
The source value is below the target's lower bound.
Defined in Unwitch.Errors
Methods
showsPrec :: Int -> Overflows -> ShowS #
show :: Overflows -> String #
showList :: [Overflows] -> ShowS #
(==) :: Overflows -> Overflows -> Bool #
(/=) :: Overflows -> Overflows -> Bool #